@@ -2,10 +2,10 @@
 Given a config file, run a given workflow
 """
 
-from management.commands import BaseCommand
-from utils.registry import registry, find_in_registry
-from workflows.base import NaiveWorkflow
-from utils.workflow import WorkflowWrapper, WorkflowLoader
+from percept.management.commands import BaseCommand
+from percept.utils.registry import registry, find_in_registry
+from percept.workflows.base import NaiveWorkflow
+from percept.utils.workflow import WorkflowWrapper, WorkflowLoader
 
 import logging
 log = logging.getLogger(__name__)
